@@ -4,7 +4,7 @@ import (
 	"context"
 	"reflect"
 
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/controller/common"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/controller/common"
 	routev1 "github.com/openshift/api/route/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
