@@ -6,8 +6,8 @@ import (
 	"time"
 
 	maistrav1 "github.com/maistra/istio-operator/pkg/apis/maistra/v1"
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/controller/common"
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/controller/resources"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/controller/common"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/controller/resources"
 	routev1 "github.com/openshift/api/route/v1"
 	"github.com/stretchr/testify/assert"
 	networkingv1 "k8s.io/api/networking/v1"
@@ -17,7 +17,6 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/client-go/kubernetes/scheme"
-	"knative.dev/pkg/kmeta"
 	"knative.dev/serving/pkg/apis/networking"
 	networkingv1alpha1 "knative.dev/serving/pkg/apis/networking/v1alpha1"
 	"knative.dev/serving/pkg/apis/serving"
@@ -153,13 +152,6 @@ func TestRouteMigration(t *testing.T) {
 				Labels: map[string]string{networking.IngressLabelKey: name, serving.RouteLabelKey: name, serving.RouteNamespaceLabelKey: namespace},
 			},
 			Spec: routev1.RouteSpec{Host: domainName},
-		}, {
-			ObjectMeta: metav1.ObjectMeta{
-				Name:      routeName0,
-				Namespace: "istio-system",
-				Labels:    map[string]string{networking.IngressLabelKey: name, serving.RouteLabelKey: name, serving.RouteNamespaceLabelKey: namespace},
-			},
-			Spec: routev1.RouteSpec{Host: domainName},
 		}, {
 			ObjectMeta: metav1.ObjectMeta{
 				Name:   "no-remove-missing-label",
@@ -175,11 +167,10 @@ func TestRouteMigration(t *testing.T) {
 		}},
 		want: []routev1.Route{{
 			ObjectMeta: metav1.ObjectMeta{
-				Name:            routeName0,
-				Namespace:       serviceMeshNamespace,
-				Labels:          map[string]string{networking.IngressLabelKey: name, serving.RouteLabelKey: name, serving.RouteNamespaceLabelKey: namespace},
-				Annotations:     map[string]string{resources.TimeoutAnnotation: "5s", networking.IngressClassAnnotationKey: network.IstioIngressClassName},
-				OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(defaultIngress)},
+				Name:        routeName0,
+				Namespace:   serviceMeshNamespace,
+				Labels:      map[string]string{networking.IngressLabelKey: name, serving.RouteLabelKey: name, serving.RouteNamespaceLabelKey: namespace},
+				Annotations: map[string]string{resources.TimeoutAnnotation: "5s", networking.IngressClassAnnotationKey: network.IstioIngressClassName},
 			},
 			Spec: routev1.RouteSpec{
 				Host: domainName,
@@ -190,6 +181,10 @@ func TestRouteMigration(t *testing.T) {
 				Port: &routev1.RoutePort{
 					TargetPort: intstr.FromString("http2"),
 				},
+				TLS: &routev1.TLSConfig{
+					Termination:                   routev1.TLSTerminationEdge,
+					InsecureEdgeTerminationPolicy: routev1.InsecureEdgeTerminationPolicyAllow,
+				},
 			},
 		}, {
 			ObjectMeta: metav1.ObjectMeta{
@@ -267,7 +262,19 @@ func TestRouteMigration(t *testing.T) {
 			t.Fatalf("failed to get ServiceMeshMemberRole: (%v)", err)
 		}
 		// Check if namespace has been removed from smmr.
-		assert.Equal(t, len([]string{}), len(smmrDelete.Spec.Members))
+		assert.Empty(t, len(smmrDelete.Spec.Members))
+
+		// check openshift routes has been removed.
+		routeListdelete := &routev1.RouteList{}
+		err = cl.List(context.TODO(), &client.ListOptions{}, routeListdelete)
+		assert.Nil(t, err)
+		assert.Empty(t, routeListdelete.Items)
+
+		// check finalizers has been removed from ingress.
+		ingressListdelete := &networkingv1alpha1.IngressList{}
+		err = cl.List(context.TODO(), &client.ListOptions{}, ingressListdelete)
+		assert.Nil(t, err)
+		assert.Empty(t, len(ingressListdelete.Items[0].Finalizers))
 	})
 }
 
@@ -313,24 +320,6 @@ func TestIngressController(t *testing.T) {
 			wantNetworkPolicy: true,
 			deleted:           false,
 		},
-		{
-			name:              "reconcile route with passthrough annotation",
-			annotations:       map[string]string{resources.TLSTerminationAnnotation: "passthrough"},
-			want:              map[string]string{resources.TLSTerminationAnnotation: "passthrough", resources.TimeoutAnnotation: "5s", networking.IngressClassAnnotationKey: network.IstioIngressClassName},
-			wantRouteErr:      func(err error) bool { return err == nil },
-			wantSmmr:          true,
-			wantNetworkPolicy: true,
-			deleted:           false,
-		},
-		{
-			name:              "reconcile route with invalid TLS termination annotation",
-			annotations:       map[string]string{resources.TLSTerminationAnnotation: "edge"},
-			want:              nil,
-			wantRouteErr:      errors.IsNotFound,
-			wantSmmr:          true,
-			wantNetworkPolicy: true,
-			deleted:           false,
-		},
 		{
 			name:              "reconcile route with different ingress annotation",
 			annotations:       map[string]string{networking.IngressClassAnnotationKey: "kourier"},
